angular.module('saixueba.utilService', [])

  .factory('RegUtil', ['warningForm', function (warningForm) {

    function trimStr(str) {
      return str.replace(/(^\s*)|(\s*$)/g, "");
    }

    function checkBiaodian(str) {
      var reg = /[\u3002|\uff1f|\uff01|\uff0c|\u3001|\uff1b|\uff1a|\u201c|\u201d|\u2018|\u2019|\uff08|\uff09|\u300a|\u300b|\u3008|\u3009|\u3010|\u3011|\u300e|\u300f|\u300c|\u300d|\ufe43|\ufe44|\u3014|\u3015|\u2026|\u2014|\uff5e|\ufe4f|\uffe5]/;
      if (reg.test(str)) {
        warningForm(null, '不能输入标点符号');
        return false;
      } else {
        return true;
      }
    }

    function checkEmoji(name) {
      var reg = new RegExp(/\uD83C[\uDF00-\uDFFF]|\uD83D[\uDC00-\uDE4F]/);
      return !reg.test(name);
    }

    function checkName(name) {
      var reg = new RegExp('^[0-9a-zA-Z\u4e00-\u9fa5]{1,10}$');
      return reg.test(name);
    }

    return {
      checkNullAndLength: function (element, mes) {
        if (element.contains(ERROR.notRequired)
          || element.contains('ng-invalid-minlength')
          || element.contains('ng-invalid-maxlength')) {
          warningForm(null, mes);
          return false;
        } else {
          return true;
        }
      },
      mobile: function (mobile) {
        var mobileReg = new RegExp('^(0|86|17951)?(13[0-9]|15[012356789]|17[0678]|18[0-9]|14[57])[0-9]{8}$');
        //var mobileReg = new RegExp('/^(0|86|17951)?(13[0-9]|15[012356789]|17[0678]|18[0-9]|14[57])[0-9]{8}$/');
        if (!(mobileReg.test(mobile))) {
          warningForm(null, '手机号格式不正确');
          return false;
        } else {
          return true;
        }
      },
      nickName: function (nickName) {
        var nickReg = new RegExp('^[\u0391-\uFFE5]+$');

        if (!(nickReg.test(nickName) && (nickName.length >= 1 && nickName.length <= 12))) {
          warningForm(null, '中文1-12个字');
          return false;
        } else {
          return true;
        }
      },
      loginName: function (name) {
        var loginNameReg = new RegExp('^[0-9a-zA-Z]{3,12}$');
        if (!loginNameReg.test(name)) {
          warningForm(null, '账号3-12位字母,数字组合,以字母开头');
          return false;
        } else {
          return true;
        }
      },
      inviteCode: function (inviteCode) {
        var passReg = new RegExp('^[0-9a-zA-Z]{4}$');
        if (!passReg.test(inviteCode)) {
          warningForm(null, '邀请码是4位字母或数字');
          return false;
        } else {
          return true;
        }
      },
      password: function (password) {
        var passReg = new RegExp('^[0-9a-zA-Z]{6,12}$');
        if (!passReg.test(password)) {
          warningForm(null, '密码6-12位字母或数字');
          return false;
        } else {
          return true;
        }
      },
      repassword: function (password, repassword) {
        if (password != repassword) {
          warningForm(null, '两次输入的密码不一致喔');
          return false;
        } else {
          return true;
        }
      },
      name: function (name) {
        var name = trimStr(name);
        if (!checkEmoji(name)) {
          warningForm(null, '不能输入表情');
          return false;
        }

        if (!checkName(name)) {
          warningForm(null, '分组名为10个之内的汉字字母数字');
          return false;
        } else {
          return true;
        }
      },
      addrees: function (addres) {
        if (!addres) {
          warningForm(null, '地址不能为空');
          return false;
        } else {
          return true;
        }
      },
      isThird: function (res) {
        var qq = false;
        var wechat = false;
        if (res.qq != "false") {
          qq = true;
          if (res.wechat != "false") {
            wechat = true;
          }
        }
        return {qq: qq, wechat: wechat};
      },
      remarkName: function (content) {
        if (!checkEmoji(content)) {
          warningForm(null, '不能输入表情喔');
          return false;
        }

        if (content.length > 50) {
          warningForm(null, '长度不能超过50个字符');
          return false;
        } else {
          return true;
        }
      }
    };
  }])




  /*-----------------------简单提示框----------------------*/
  .factory('warningForm', ['$timeout', '$ionicLoading', function ($timeout, $ionicLoading) {
    return function (iElm, txt) {
      if (!txt) {
        return;
      }

      $ionicLoading.show({
        template: txt,
        noBackdrop: true
      });

      $timeout(function () {
        $ionicLoading.hide();
      }, txt.length * 80 < 1500 ? 1500 : txt.length * 80);
    }
  }])

  /*--------------  简单confirm确认框 ----------------*/
  .service('ConfirmService', ['$ionicPopup', function ($ionicPopup) {

    var init = function (title, template) {

      return promise = $ionicPopup.confirm({
        title: title,
        template: template,
        okText: "确定",
        cancelText: "取消"
      });
    }

    return {
      init: init
    }
  }])

  /*--------------  alert提示框 ----------------*/
  .service('AlertService', ['$ionicPopup', function ($ionicPopup) {
    var init = function (title, template) {

      return promise = $ionicPopup.alert({
        title: title,
        template: template,
        okText: "确定"
      });
    }

    return {
      init: init
    }
  }])
  .factory('Storage', function () {
    function localClear() {
      var str = Wosaiteach.locStoPre + "." + "init_";
      for (var p in localStorage) {
        var fdStart = p.indexOf(str);
        if (fdStart != 0 && fdStart) {
          localStorage.removeItem(p);
        }
      }
    }

    return {
      set: function (key, data) {
        var newKey = Wosaiteach.locStoPre + "." + key;
        // return window.localStorage.setItem(newKey, window.JSON.stringify(data));
        return localStorageService.set(newKey, data);
      },
      get: function (key) {
        var newKey = Wosaiteach.locStoPre + "." + key;
        return window.JSON.parse(window.localStorage.getItem(newKey));
      },
      remove: function (key) {
        var newKey = Wosaiteach.locStoPre + "." + key;
        return window.localStorage.removeItem(newKey);
      },
      clearAll: function () {
        localClear();
      }
    };
  })
;

